@@ -1,7 +1,6 @@
 from __future__ import annotations
 
-from dask_gateway_server.options import Options, Select
-
+import shutil
 from aws_pcluster_helpers.models.sinfo import (SInfoTable, SinfoRow)
 import functools
 import os
@@ -42,7 +41,8 @@ from aws_pcluster_helpers.models.config import PClusterConfigFiles
 from traitlets import Unicode, default
 from traitlets import Bool, Float, Integer, List, Unicode, default, validate
 
-from dask_gateway_server.backends.jobqueue.slurm import SlurmClusterConfig, SlurmBackend
+from dask_gateway_server.backends.jobqueue.slurm import SlurmClusterConfig, SlurmBackend, slurm_format_memory
+from dask_gateway_server.options import Options, Select
 from dask_gateway_server.options import Options, Select, String
 from dask_gateway_server.traitlets import Command, Type
 
@@ -66,7 +66,9 @@ class DaskGatewaySlurmConfig(sinfo.SInfoTable):
             label = f"P: {sinfo_row.queue}, I: {sinfo_row.ec2_instance_type}, CPU: {sinfo_row.vcpu}, Mem: {sinfo_row.mem}"
             profiles[label] = {
                 "worker_cores": sinfo_row.vcpu,
-                "worker_memory": sinfo_row.mem,
+                "scheduler_cores": sinfo_row.vcpu,
+                "worker_memory": f"{sinfo_row.mem} G",
+                "scheduler_memory": f"{sinfo_row.mem} G",
                 "constraint": sinfo_row.constraint,
                 "partition": sinfo_row.queue,
             }
@@ -176,7 +178,11 @@ class PClusterBackend(SlurmBackend):
     )
 
     def get_submit_cmd_env_stdin(self, cluster, worker=None):
-        cmd = [self.submit_command, "--parsable", "--job-name=dask-gateway"]
+        cmd = []
+        if worker:
+            cmd = [self.submit_command, "--parsable", "--job-name=dask-gateway"]
+        else:
+            cmd = [self.submit_command, "--parsable", "--job-name=dask-gateway"]
         if cluster.config.partition:
             cmd.append("--partition=" + str(cluster.config.partition))
         if cluster.config.account:
